pub fn required_bump(commits: &[ConventionalCommit]) -> Option<BumpLevel>Expand description
Determine the strongest bump the commits require, or None when no commit
warrants a release.
pub fn required_bump(commits: &[ConventionalCommit]) -> Option<BumpLevel>Determine the strongest bump the commits require, or None when no commit
warrants a release.