pub fn plan_version_rewrite(
repo_root: &Path,
new_version: &str,
) -> Result<VersionRewritePlan>Expand description
Plan the rewrite of every member manifest and the lockfile to
new_version, without touching the filesystem.
pub fn plan_version_rewrite(
repo_root: &Path,
new_version: &str,
) -> Result<VersionRewritePlan>Plan the rewrite of every member manifest and the lockfile to
new_version, without touching the filesystem.